@@ -57,7 +57,7 @@ def parse_headers(header_list):
 
 def serialize_headers(response):
     out = {}
-    for key, values in compat.get_headers(response):
+    for key, values in compat.get_headers(response.msg):
         out.setdefault(key, [])
         out[key].extend(values)
     return out
@@ -108,14 +108,18 @@ class VCRHTTPResponse(HTTPResponse):
 
     def getheaders(self):
         message = parse_headers(self.recorded_response['headers'])
-        return compat.get_header_items(message)
+        return list(compat.get_header_items(message))
 
     def getheader(self, header, default=None):
-        headers = dict(((k.lower(), v) for k, v in self.getheaders()))
-        return headers.get(header.lower(), default)
+        values = [v for (k, v) in self.getheaders() if k.lower() == header.lower()]
+
+        if values:
+            return ', '.join(values)
+        else:
+            return default
 
 
-class VCRConnection:
+class VCRConnection(object):
     # A reference to the cassette that's currently being patched in
     cassette = None
 
@@ -201,7 +205,7 @@ class VCRConnection:
         pass
 
     def getresponse(self, _=False):
-        '''Retrieve a the response'''
+        '''Retrieve the response'''
         # Check to see if the cassette has a response for this request. If so,
         # then return it
         if self.cassette.can_play_response_for(self._vcr_request):
@@ -291,10 +295,9 @@ class VCRConnection:
         # need to temporarily reset here because the real connection
         # inherits from the thing that we are mocking out.  Take out
         # the reset if you want to see what I mean :)
-        from vcr.patch import install, reset
-        reset()
-        self.real_connection = self._baseclass(*args, **kwargs)
-        install(self.cassette)
+        from vcr.patch import force_reset
+        with force_reset():
+            self.real_connection = self._baseclass(*args, **kwargs)
 
 
 class VCRHTTPConnection(VCRConnection):
